localize-cli
============

This package provides a unified command line interface to Localize.

Platforms
---------

- Mac OS X
- Windows
- Linux

--------------------
Installation & Usage
--------------------

For an installation and usage guide please refer to our `help docs <https://help.localizejs.com/docs/localize-cli>`_.

---------------
Issues
---------------

If you have an issue, please look at our `Common Issues <https://github.com/Localize/localize-cli/wiki/Common-Issues>`_ for solutions first. If no solution is found, feel free to make an issue or contact `support <https://localizejs.com/company/contact>`_.
